try{!function(){var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},n=(new e.Error).stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="d13d9dd4-bbd3-4efc-8d3b-3caa31cda033",e._sentryDebugIdIdentifier="sentry-dbid-d13d9dd4-bbd3-4efc-8d3b-3caa31cda033")}()}catch(e){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.06.02-8c11d9f"}}catch(e){}}(),exports.id=4128,exports.ids=[4128],exports.modules={"./src/commands/uninstall-shell-integration.ts":(e,n,t)=>{t.r(n),t.d(n,{handleUninstallShellIntegration:()=>c});var i=t("node:fs"),l=t("node:os"),o=t("node:path"),d=t.n(o),s=t("./src/console-io.ts");const a='eval "$(~/.local/bin/agent shell-integration zsh)"',r='eval "$(~/.local/bin/cursor-agent shell-integration zsh)"';function c(){const e=d().join((0,l.homedir)(),".zshrc");try{let n="";try{n=(0,i.readFileSync)(e,"utf8")}catch(e){if("ENOENT"===e.code)return void(0,s.p2)("~/.zshrc file not found. Shell integration is not installed.");throw e}if(!n.includes(a)&&!n.includes(r))return void(0,s.p2)("Shell integration is not installed in ~/.zshrc");const t=n.split("\n"),l=t.filter((e=>e.trim()!==a&&e.trim()!==r));t[0]!==a&&t[0]!==r||""!==t[1]||l.shift();const o=l.join("\n");(0,i.writeFileSync)(e,o,"utf8"),(0,s.p2)("Shell integration uninstalled successfully!"),(0,s.p2)("Please restart your terminal for changes to take effect.")}catch(e){(0,s.p2)(`Failed to uninstall shell integration: ${String(e)}`),process.exit(1)}}}};