try{!function(){var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},n=(new e.Error).stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="367ab119-9518-4bce-8289-9d04538cdd51",e._sentryDebugIdIdentifier="sentry-dbid-367ab119-9518-4bce-8289-9d04538cdd51")}()}catch(e){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.06.02-8c11d9f"}}catch(e){}}(),exports.id=3746,exports.ids=[3746],exports.modules={"./src/commands/disable.ts":(e,n,d)=>{d.r(n),d.d(n,{handleMcpDisable:()=>l});var o=d("../../node_modules/.pnpm/chalk@5.4.1/node_modules/chalk/source/index.js"),s=d("./src/console-io.ts"),t=d("./src/mcp/disabled-store.ts"),i=d("./src/mcp/project-paths.ts"),r=function(e,n,d,o){return new(d||(d=Promise))((function(s,t){function i(e){try{l(o.next(e))}catch(e){t(e)}}function r(e){try{l(o.throw(e))}catch(e){t(e)}}function l(e){var n;e.done?s(e.value):(n=e.value,n instanceof d?n:new d((function(e){e(n)}))).then(i,r)}l((o=o.apply(e,n||[])).next())}))};function l(e,n){return r(this,void 0,void 0,(function*(){var e;try{const e=process.cwd(),{disabledPath:d}=(0,i.C)(e),r=new t.P(d),l=yield r.isServerDisabled(n);l||(yield r.addDisabledServer(n)),l?(0,s.OT)(o.Ay.yellow(`MCP server '${n}' was already disabled`)):(0,s.OT)(o.Ay.green(`✓ Disabled MCP server: ${n}`)+"\n"+o.Ay.dim("The server will no longer be loaded or prompted for approval.")),process.exit(0)}catch(n){const d=null!==(e=null==n?void 0:n.message)&&void 0!==e?e:String(n);(0,s.p2)(o.Ay.red(`Failed to disable MCP server: ${d}`)),process.exit(1)}}))}}};