try{!function(){var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},r=(new e.Error).stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="0dd1fc98-5f12-4145-b3bc-2b879e806e21",e._sentryDebugIdIdentifier="sentry-dbid-0dd1fc98-5f12-4145-b3bc-2b879e806e21")}()}catch(e){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.06.02-8c11d9f"}}catch(e){}}(),exports.id=1425,exports.ids=[1425],exports.modules={"./src/utils/labels-file-parser.ts":(e,r,n)=>{n.r(r),n.d(r,{parseJsonLabelsFile:()=>t,parseTomlLabelsFile:()=>s});var o=n("../../node_modules/.pnpm/smol-toml@1.5.2/node_modules/smol-toml/dist/index.js");function t(e,r){const n=JSON.parse(e);if(Array.isArray(n)){const e=[];for(const o of n){if("object"!=typeof o||null===o||!("key"in o)||!("value"in o)||"string"!=typeof o.key||"string"!=typeof o.value)throw new Error(`Invalid label entry in ${r}: expected {key: string, value: string}`);e.push({key:o.key,value:o.value})}return e}if("object"==typeof n&&null!==n){const e=[];for(const[o,t]of Object.entries(n))if("string"==typeof t)e.push({key:o,value:t});else{if(!Array.isArray(t))throw new Error(`Invalid label value for key "${o}" in ${r}: expected string or array of strings`);for(const n of t){if("string"!=typeof n)throw new Error(`Invalid label value for key "${o}" in ${r}: array values must be strings`);e.push({key:o,value:n})}}return e}throw new Error(`Invalid labels file format in ${r}: expected array or object`)}function s(e,r){const n=(0,o.qg)(e),t=[];for(const[e,o]of Object.entries(n))if("string"==typeof o)t.push({key:e,value:o});else{if(!Array.isArray(o))throw new Error(`Invalid label value for key "${e}" in ${r}: expected string or array of strings`);for(const n of o){if("string"!=typeof n)throw new Error(`Invalid label value for key "${e}" in ${r}: array values must be strings`);t.push({key:e,value:n})}}return t}}};