try{!function(){var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},n=(new e.Error).stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="3a6ee590-0b15-4247-9d28-40b182b7e96d",e._sentryDebugIdIdentifier="sentry-dbid-3a6ee590-0b15-4247-9d28-40b182b7e96d")}()}catch(e){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.06.02-8c11d9f"}}catch(e){}}(),exports.id=945,exports.ids=[945],exports.modules={"./src/commands/repo-status.tsx":(e,n,t)=>{t.r(n),t.d(n,{handleRepoStatus:()=>d});var o=t("./src/console-io.ts"),i=function(e,n,t,o){return new(t||(t=Promise))((function(i,d){function s(e){try{f(o.next(e))}catch(e){d(e)}}function r(e){try{f(o.throw(e))}catch(e){d(e)}}function f(e){var n;e.done?i(e.value):(n=e.value,n instanceof t?n:new t((function(e){e(n)}))).then(s,r)}f((o=o.apply(e,n||[])).next())}))};function d(e){return i(this,void 0,void 0,(function*(){try{const n=yield e.getIndexingStatus();(0,o.OT)(JSON.stringify(n,null,2))}catch(e){(0,o.p2)(e instanceof Error?e.message:String(e))}process.exit(0)}))}}};