try{!function(){var n="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},e=(new n.Error).stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="cb231014-8f0a-4185-8402-bfc44089aa15",n._sentryDebugIdIdentifier="sentry-dbid-cb231014-8f0a-4185-8402-bfc44089aa15")}()}catch(n){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.06.02-8c11d9f"}}catch(n){}}(),exports.id=1832,exports.ids=[1832],exports.modules={"./src/commands/sandbox-config.ts":(n,e,s)=>{s.r(e),s.d(e,{handleSandboxDisable:()=>c,handleSandboxEnable:()=>b,handleSandboxReset:()=>l});var o=s("../shell-exec/dist/index.js"),t=s("./src/console-io.ts"),a=s("./src/sandbox-gate.ts"),i=s("./src/utils/sandbox-messages.ts"),d=function(n,e,s,o){return new(s||(s=Promise))((function(t,a){function i(n){try{r(o.next(n))}catch(n){a(n)}}function d(n){try{r(o.throw(n))}catch(n){a(n)}}function r(n){var e;n.done?t(n.value):(e=n.value,e instanceof s?e:new s((function(n){n(e)}))).then(i,d)}r((o=o.apply(n,e||[])).next())}))},r=function(n,e){var s={};for(var o in n)Object.prototype.hasOwnProperty.call(n,o)&&e.indexOf(o)<0&&(s[o]=n[o]);if(null!=n&&"function"==typeof Object.getOwnPropertySymbols){var t=0;for(o=Object.getOwnPropertySymbols(n);t<o.length;t++)e.indexOf(o[t])<0&&Object.prototype.propertyIsEnumerable.call(n,o[t])&&(s[o[t]]=n[o[t]])}return s};function b(n){return d(this,void 0,void 0,(function*(){(0,a.Y)()&&(0,o.K3)()||(yield n.transform((n=>Object.assign(Object.assign({},n),{sandbox:Object.assign(Object.assign({},n.sandbox),{mode:"disabled"})}))),(0,t.OT)(`Error: Sandbox is not available on this system. ${(0,i.l)()}.`),process.exit(1)),yield n.transform((n=>Object.assign(Object.assign({},n),{sandbox:Object.assign(Object.assign({},n.sandbox),{mode:"enabled"})}))),(0,t.OT)("✅ Sandbox mode enabled. Commands will now run in a sandbox environment."),(0,t.OT)("💡 Use 'agent sandbox disable' to switch back to allowlist mode."),process.exit(0)}))}function c(n){return d(this,void 0,void 0,(function*(){yield n.transform((n=>Object.assign(Object.assign({},n),{sandbox:Object.assign(Object.assign({},n.sandbox),{mode:"disabled"})}))),(0,t.OT)("✅ Sandbox mode disabled. Commands will now use allowlist mode (default)."),(0,t.OT)("💡 Use 'agent sandbox enable' to switch back to sandbox mode."),process.exit(0)}))}function l(n){return d(this,void 0,void 0,(function*(){yield n.transform((n=>{const{sandbox:e}=n,s=r(n,["sandbox"]);return Object.assign(Object.assign({},s),{showSandboxIntro:!0})})),(0,t.OT)("✅ Sandbox configuration reset. All sandbox-specific settings have been removed."),(0,t.OT)("💡 Use 'agent sandbox enable' to configure sandbox mode again."),process.exit(0)}))}},"./src/sandbox-gate.ts":(n,e,s)=>{s.d(e,{Y:()=>d});var o=s("./src/statsig.ts");const t="composer_sandbox_settings_visible",a="sandbox_force_disable_win32";function i(n,e){return(0,o.mD)()?(0,o.QF)(n):e}function d(n="darwin"){return!(!i(t,!0)||"win32"===n&&i(a,!0))}},"./src/utils/sandbox-messages.ts":(n,e,s)=>{function o(){return"Sandbox is unavailable"}s.d(e,{l:()=>o}),s("node:os")}};